/**
 * Lazy map
 *
 * @export
 * @class LazyMap
 * @template K
 * @template V
 */
export declare class LazyMap<K, V> {
    /**
     * Map backend instance for non initialized lazy map
     *
     * @private
     */
    private map;
    /**
     * Creates an instance of LazyMap.
     * @param [entries]
     */
    constructor(entries?: Array<[K, V]>);
    /**
     * Clear map
     *
     * @param [deleteEntities=false] Also delete entties
     * @returns
     */
    clear(deleteEntities?: boolean): Promise<void>;
    /**
     * Delete value by key
     *
     * @param key
     * @param [deleteEntity=false] Also delete corresponding entity
     * @returns
     */
    delete(key: K, deleteEntity?: boolean): Promise<boolean>;
    /**
     * Get value by key
     *
     * @param key
     * @returns
     */
    get(key: K): Promise<V | undefined>;
    /**
     * Check if has value by key
     *
     * @param key
     * @returns
     */
    has(key: K): Promise<boolean>;
    /**
     * Set new value
     *
     * @param key
     * @param value
     * @returns
     */
    set(key: K, value: V): Promise<void>;
    /**
     * Map size
     *
     * @returns
     */
    size(): Promise<number>;
    /**
     * Convert to array
     *
     * @returns
     */
    toArray(): Promise<Array<[K, V]>>;
    /**
     * Keys iterator
     *
     * @returns
     */
    keys(): AsyncIterableIterator<K>;
    /**
     * Values iterator
     *
     * @returns
     */
    values(): AsyncIterableIterator<V>;
    /**
     * Map iterator
     *
     * @returns
     */
    [Symbol.asyncIterator](): AsyncIterableIterator<[K, V]>;
}
