"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __await = (this && this.__await) || function (v) { return this instanceof __await ? (this.v = v, this) : new __await(v); }
var __asyncGenerator = (this && this.__asyncGenerator) || function (thisArg, _arguments, generator) {
    if (!Symbol.asyncIterator) throw new TypeError("Symbol.asyncIterator is not defined.");
    var g = generator.apply(thisArg, _arguments || []), i, q = [];
    return i = {}, verb("next"), verb("throw"), verb("return"), i[Symbol.asyncIterator] = function () { return this; }, i;
    function verb(n) { if (g[n]) i[n] = function (v) { return new Promise(function (a, b) { q.push([n, v, a, b]) > 1 || resume(n, v); }); }; }
    function resume(n, v) { try { step(g[n](v)); } catch (e) { settle(q[0][3], e); } }
    function step(r) { r.value instanceof __await ? Promise.resolve(r.value.v).then(fulfill, reject) : settle(q[0][2], r);  }
    function fulfill(value) { resume("next", value); }
    function reject(value) { resume("throw", value); }
    function settle(f, v) { if (f(v), q.shift(), q.length) resume(q[0][0], q[0][1]); }
};
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * Lazy map
 *
 * @export
 * @class LazyMap
 * @template K
 * @template V
 */
class LazyMap {
    /**
     * Creates an instance of LazyMap.
     * @param [entries]
     */
    constructor(entries) {
        this.map = new Map(entries);
    }
    /**
     * Clear map
     *
     * @param [deleteEntities=false] Also delete entties
     * @returns
     */
    clear(deleteEntities = false) {
        return __awaiter(this, void 0, void 0, function* () {
            this.map.clear();
        });
    }
    /**
     * Delete value by key
     *
     * @param key
     * @param [deleteEntity=false] Also delete corresponding entity
     * @returns
     */
    delete(key, deleteEntity = false) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.map.delete(key);
        });
    }
    /**
     * Get value by key
     *
     * @param key
     * @returns
     */
    get(key) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.map.get(key);
        });
    }
    /**
     * Check if has value by key
     *
     * @param key
     * @returns
     */
    has(key) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.map.has(key);
        });
    }
    /**
     * Set new value
     *
     * @param key
     * @param value
     * @returns
     */
    set(key, value) {
        return __awaiter(this, void 0, void 0, function* () {
            this.map.set(key, value);
        });
    }
    /**
     * Map size
     *
     * @returns
     */
    size() {
        return __awaiter(this, void 0, void 0, function* () {
            return this.map.size;
        });
    }
    /**
     * Convert to array
     *
     * @returns
     */
    toArray() {
        return __awaiter(this, void 0, void 0, function* () {
            return [...this.map];
        });
    }
    /**
     * Keys iterator
     *
     * @returns
     */
    keys() {
        return __asyncGenerator(this, arguments, function* keys_1() {
            for (const k of this.map.keys()) {
                yield k;
            }
        });
    }
    /**
     * Values iterator
     *
     * @returns
     */
    values() {
        return __asyncGenerator(this, arguments, function* values_1() {
            for (const v of this.map.values()) {
                yield v;
            }
        });
    }
    /**
     * Map iterator
     *
     * @returns
     */
    [Symbol.asyncIterator]() {
        return __asyncGenerator(this, arguments, function* _a() {
            for (const val of this.map) {
                yield val;
            }
        });
    }
}
exports.LazyMap = LazyMap;
//# sourceMappingURL=LazyMap.js.map