/**
 * Lazy set
 *
 * @export
 * @class LazySet
 * @template T
 */
export declare class LazySet<T> {
    /**
     * Set instance
     *
     * @private
     */
    private set;
    /**
     * Creates an instance of LazySet.
     * @param [values]
     */
    constructor(values?: T[]);
    /**
     * Add value to the set
     *
     * @param value
     * @returns
     */
    add(value: T): Promise<void>;
    /**
     * Delete value from the set
     *
     * @param value
     * @param [deleteEntity=false] Also delete entity if it's entity set
     * @returns
     */
    delete(value: T, deleteEntity?: boolean): Promise<boolean>;
    /**
     * Check if has value in the set
     *
     * @param value
     * @returns
     */
    has(value: T): Promise<boolean>;
    /**
     * Get set size
     *
     * @returns
     */
    size(): Promise<number>;
    /**
     * Clear set
     *
     * @param [deleteEntities=false] Also delete all entities
     * @returns
     */
    clear(deleteEntities?: boolean): Promise<void>;
    /**
     * Get all values in array
     *
     * @returns
     */
    toArray(): Promise<T[]>;
    /**
     * Iterate over values
     */
    values(): AsyncIterableIterator<T>;
    /**
     * Iterate over values
     *
     */
    [Symbol.asyncIterator](): AsyncIterableIterator<T>;
    [Symbol.iterator](): IterableIterator<T>;
}
