"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __await = (this && this.__await) || function (v) { return this instanceof __await ? (this.v = v, this) : new __await(v); }
var __asyncGenerator = (this && this.__asyncGenerator) || function (thisArg, _arguments, generator) {
    if (!Symbol.asyncIterator) throw new TypeError("Symbol.asyncIterator is not defined.");
    var g = generator.apply(thisArg, _arguments || []), i, q = [];
    return i = {}, verb("next"), verb("throw"), verb("return"), i[Symbol.asyncIterator] = function () { return this; }, i;
    function verb(n) { if (g[n]) i[n] = function (v) { return new Promise(function (a, b) { q.push([n, v, a, b]) > 1 || resume(n, v); }); }; }
    function resume(n, v) { try { step(g[n](v)); } catch (e) { settle(q[0][3], e); } }
    function step(r) { r.value instanceof __await ? Promise.resolve(r.value.v).then(fulfill, reject) : settle(q[0][2], r);  }
    function fulfill(value) { resume("next", value); }
    function reject(value) { resume("throw", value); }
    function settle(f, v) { if (f(v), q.shift(), q.length) resume(q[0][0], q[0][1]); }
};
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * Lazy set
 *
 * @export
 * @class LazySet
 * @template T
 */
class LazySet {
    /**
     * Creates an instance of LazySet.
     * @param [values]
     */
    constructor(values) {
        this.set = new Set(values);
    }
    /**
     * Add value to the set
     *
     * @param value
     * @returns
     */
    add(value) {
        return __awaiter(this, void 0, void 0, function* () {
            this.set.add(value);
        });
    }
    /**
     * Delete value from the set
     *
     * @param value
     * @param [deleteEntity=false] Also delete entity if it's entity set
     * @returns
     */
    delete(value, deleteEntity = false) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.set.delete(value);
        });
    }
    /**
     * Check if has value in the set
     *
     * @param value
     * @returns
     */
    has(value) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.set.has(value);
        });
    }
    /**
     * Get set size
     *
     * @returns
     */
    size() {
        return __awaiter(this, void 0, void 0, function* () {
            return this.set.size;
        });
    }
    /**
     * Clear set
     *
     * @param [deleteEntities=false] Also delete all entities
     * @returns
     */
    clear(deleteEntities = false) {
        return __awaiter(this, void 0, void 0, function* () {
            this.set.clear();
        });
    }
    /**
     * Get all values in array
     *
     * @returns
     */
    toArray() {
        return __awaiter(this, void 0, void 0, function* () {
            return [...this.set.values()];
        });
    }
    /**
     * Iterate over values
     */
    values() {
        return __asyncGenerator(this, arguments, function* values_1() {
            for (const val of this.set.values()) {
                yield val;
            }
        });
    }
    /**
     * Iterate over values
     *
     */
    [Symbol.asyncIterator]() {
        return __asyncGenerator(this, arguments, function* _a() {
            for (const val of this.set) {
                yield val;
            }
        });
    }
    *[Symbol.iterator]() {
        for (const val of this.set) {
            yield Promise.resolve(val);
        }
    }
}
exports.LazySet = LazySet;
//# sourceMappingURL=LazySet.js.map