import { LazyMap } from "../Collections/LazyMap";
import { EntityType, RedisManager } from "../Persistence/RedisManager";
export declare class RedisLazyMap<K, V> extends LazyMap<K, V> {
    /**
     * Manager instance
     *
     * @private
     */
    private manager;
    /**
     * Map id
     *
     * @private
     */
    private mapId;
    /**
     * Entity class
     *
     * @private
     */
    private entityClass?;
    /**
     * Cascade inserting
     *
     * @private
     */
    private cascadeInsert;
    /**
     * Creates an instance of RedisLazyMap.
     * @param mapId Full map id in redis
     * @param manager Manager instance
     * @param [entityClass] If passed then map will be treated as entity map and will set/return entities
     * @param [cascadeInsert=false] True to automatically save entities
     */
    constructor(mapId: string, manager: RedisManager, entityClass?: EntityType<V>, cascadeInsert?: boolean);
    /**
     * Get map size
     *
     * @returns
     */
    size(): Promise<number>;
    /**
     * Set value
     *
     * @param key
     * @param value
     * @returns
     */
    set(key: K, value: V): Promise<void>;
    /**
     * Delete value by key
     *
     * @param key
     * @param [deleteEntity=false] Also delete corresponding entity
     * @returns
     */
    delete(key: K, deleteEntity?: boolean): Promise<boolean>;
    /**
     * Check if the map has key
     *
     * @param key
     * @returns
     */
    has(key: K): Promise<boolean>;
    /**
     * Get the value by given key
     *
     * @param key
     * @returns
     */
    get(key: K): Promise<V | undefined>;
    /**
     * Clear map
     *
     * @param [deleteEntities=false] Also delete entties
     * @returns
     */
    clear(deleteEntities?: boolean): Promise<void>;
    /**
     * Convert map to array
     *
     * @returns
     */
    toArray(): Promise<Array<[K, V]>>;
    /**
     * Iterate over map keys => values
     *
     * @returns
     */
    [Symbol.asyncIterator](): AsyncIterableIterator<[K, V]>;
    /**
     * Iterate over map's keys
     *
     * @returns
     */
    keys(): AsyncIterableIterator<K>;
    /**
     * Iterate over map's values
     *
     * @returns
     */
    values(): AsyncIterableIterator<V>;
}
