import { LazySet } from "../Collections/LazySet";
import { EntityType, RedisManager } from "../Persistence/RedisManager";
/**
 * Redis-backed lazy set
 *
 * @export
 * @class RedisLazySet
 * @template T
 */
export declare class RedisLazySet<T> extends LazySet<T> {
    /**
     * Manager instance
     *
     * @private
     */
    private manager;
    /**
     * Full set id
     *
     * @private
     */
    private setId;
    /**
     * Entity class
     *
     * @private
     */
    private entityClass?;
    /**
     * Cascade insert related entities
     *
     * @private
     */
    private cascadeInsert;
    /**
     * Creates an instance of RedisLazySet.
     * @param setId Full set id in redis
     * @param manager Manager instance
     * @param [entityClass] If passed then set will be treated as entity set and will return entities
     */
    constructor(setId: string, manager: RedisManager, entityClass?: EntityType<T>, cascadeInsert?: boolean);
    /**
     * Add value or entity to the set
     *
     * @param value
     * @returns
     */
    add(value: T): Promise<void>;
    /**
     * Remove value or entity from the set.
     *
     * @param value
     * @param [deleteEntity=false]
     * @returns
     */
    delete(value: T, deleteEntity?: boolean): Promise<boolean>;
    /**
     * Determine if value or entity exists in the set
     *
     * @param value
     * @returns
     */
    has(value: T): Promise<boolean>;
    /**
     * Get size of set
     *
     * @returns
     */
    size(): Promise<number>;
    /**
     * Clear set
     *
     * @param [deleteEntities=false] Also delete all entities
     * @returns
     */
    clear(deleteEntities?: boolean): Promise<void>;
    /**
     * Convert set to array
     *
     * @returns
     */
    toArray(): Promise<T[]>;
    /**
     * Iterate over values
     */
    values(): AsyncIterableIterator<T>;
    /**
     * Iterator over values
     *
     * @returns
     */
    [Symbol.asyncIterator](): AsyncIterableIterator<T>;
}
