"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const Metadata_1 = require("../Metadata/Metadata");
/**
 * Defines identify property for given redis hash.
 * Hash must contain one IdentifyProperty
 *
 * @export
 * @param type Type
 * @param [name] Redis property name
 * @returns
 */
function IdentifyProperty(nameOrType, type) {
    return function (target, propertyKey) {
        const designType = Reflect.getMetadata("design:type", target, propertyKey);
        const name = typeof nameOrType === "string" ? nameOrType : propertyKey;
        const propertyType = typeof nameOrType === "function"
            ? nameOrType
            : type
                ? type
                : designType;
        if (propertyType !== String && propertyType !== Number) {
            throw new Error("Identify property must be string or number type");
        }
        const properties = Reflect.getMetadata(Metadata_1.REDIS_PROPERTIES, target.constructor) || [];
        properties.push({
            propertyName: propertyKey,
            propertyRedisName: name,
            isIdentifyColumn: true,
            propertyType: propertyType,
            isRelation: false
        });
        Reflect.defineMetadata(Metadata_1.REDIS_PROPERTIES, properties, target.constructor);
    };
}
exports.IdentifyProperty = IdentifyProperty;
//# sourceMappingURL=IdentifyProperty.js.map