import { Connection, ConnectionOptions } from "../Connection/Connection";
import * as redis from "../utils/PromisedRedis";
/**
 * Get available database from pool of databases (presented as SET in redis)
 *
 * @returns
 */
export declare function getAvailableDatabase(): Promise<string>;
/**
 * Release available database and return it to the pool
 *
 * @export
 * @param dbNumber
 * @returns
 */
export declare function releaseDatabase(dbNumber: string): Promise<void>;
/**
 * Create redis client
 *
 * @export
 * @returns
 */
export declare function createRawRedisClient(): redis.RedisClient;
/**
 * Create redis connection
 *
 * @param [options={}]
 * @export
 * @returns
 */
export declare function createRedisConnection(options?: ConnectionOptions): Promise<Connection>;
/**
 * Clean & release redis connection
 *
 * @export
 * @param connection
 * @returns
 */
export declare function cleanRedisConnection(connection: Connection): Promise<void>;
/**
 * Return database number used for connection
 *
 * @export
 * @param connection
 * @returns
 */
export declare function getDatabaseNumberForConnection(connection: Connection): string | undefined;
